Crate av1an_core

Crate av1an_core 

Modules

ffmpeg
vapoursynth

Macros

count
Count the number of elements passed to this macro.
create_dir
Attempts to create the directory if it does not exist, logging and returning and error if creating the directory failed.
inplace_vec
Equivalent to into_vec! when the inferred type is Cow<'_, str>.
into_array
into_smallvec
into_vec
ref_smallvec

Structs

Av1anContext
ClipInfo
EncodeArgs
PixelFormat
ProbingStatistic
TargetQuality

Enums

ChunkMethod
ChunkOrdering
ConcatMethod
Encoder
Input
InputPixelFormat
InterpolationMethod
ProbingStatisticName
ScenecutMethod
SplitMethod
TargetMetric
Verbosity
VmafFeature

Functions

determine_workers
Determine the optimal number of workers for an encoder
hash_path
list_index
read_in_dir
Reads dir and returns all files Depth 1