Enum av1an_core::encoder::Encoder[][src]

pub enum Encoder {
    aom,
    rav1e,
    vpx,
    svt_av1,
    x264,
    x265,
}

Variants

aom

rav1e

vpx

svt_av1

x264

x265

Implementations

Composes 1st pass command for 1 pass encoding

Composes 1st pass command for 2 pass encoding

Composes 2st pass command for 2 pass encoding

Returns default settings for the encoder

Return number of default passes for encoder

Default quantizer range target quality mode

Returns help command for encoder

Get the name of the executable/binary for the encoder

Get the default output extension for the encoder

Returns changed q/crf in command line arguments

Returns command used for target quality probing

Returns command used for target quality probing (slow, correctness focused version)

Function remove_patterns that takes in args and patterns and removes all instances of the patterns from the args.

Constructs tuple of commands for target quality probing