pub enum Encoder {
aom,
rav1e,
vpx,
svt_av1,
x264,
x265,
}Variants
Implementations
Sourceimpl Encoder
impl Encoder
Sourcepub fn compose_1_1_pass(
self,
params: Vec<String>,
output: String,
) -> Vec<String>
pub fn compose_1_1_pass( self, params: Vec<String>, output: String, ) -> Vec<String>
Composes 1st pass command for 1 pass encoding
Sourcepub fn compose_1_2_pass(self, params: Vec<String>, fpf: &str) -> Vec<String>
pub fn compose_1_2_pass(self, params: Vec<String>, fpf: &str) -> Vec<String>
Composes 1st pass command for 2 pass encoding
Sourcepub fn compose_2_2_pass(
self,
params: Vec<String>,
fpf: &str,
output: String,
) -> Vec<String>
pub fn compose_2_2_pass( self, params: Vec<String>, fpf: &str, output: String, ) -> Vec<String>
Composes 2st pass command for 2 pass encoding
Sourcepub fn get_default_arguments(self, (cols, rows): (u32, u32)) -> Vec<String>
pub fn get_default_arguments(self, (cols, rows): (u32, u32)) -> Vec<String>
Returns default settings for the encoder
Sourcepub const fn get_default_pass(self) -> u8
pub const fn get_default_pass(self) -> u8
Return number of default passes for encoder
Sourcepub const fn get_default_cq_range(self) -> (usize, usize)
pub const fn get_default_cq_range(self) -> (usize, usize)
Default quantizer range target quality mode
Sourcepub fn get_cq_relative_percentage(self, quantizer: usize) -> f64
pub fn get_cq_relative_percentage(self, quantizer: usize) -> f64
Returns quantizer percentage (0-1) relative to entire range for encoder
Sourcepub const fn help_command(self) -> [&'static str; 2]
pub const fn help_command(self) -> [&'static str; 2]
Returns help command for encoder
Sourcepub fn version_text(self) -> Option<String>
pub fn version_text(self) -> Option<String>
Returns version text for encoder, or None if encoder is not available in PATH
Sourcepub const fn format(self) -> &'static str
pub const fn format(self) -> &'static str
Get the name of the video format associated with the encoder
Sourcepub const fn output_extension(&self) -> &'static str
pub const fn output_extension(&self) -> &'static str
Get the default output extension for the encoder
Sourcepub fn man_command(self, params: Vec<String>, q: f32) -> Vec<String>
pub fn man_command(self, params: Vec<String>, q: f32) -> Vec<String>
Returns changed q/crf in command line arguments
Sourcepub fn construct_target_quality_command(
self,
threads: usize,
q: f32,
) -> Vec<Cow<'static, str>>
pub fn construct_target_quality_command( self, threads: usize, q: f32, ) -> Vec<Cow<'static, str>>
Returns command used for target quality probing
Sourcepub fn construct_target_quality_command_probe_slow(
self,
q: f32,
) -> Vec<Cow<'static, str>>
pub fn construct_target_quality_command_probe_slow( self, q: f32, ) -> Vec<Cow<'static, str>>
Returns command used for target quality probing (slow, correctness focused version)
Sourcepub fn remove_patterns(args: &mut Vec<String>, patterns: &[&str])
pub fn remove_patterns(args: &mut Vec<String>, patterns: &[&str])
Function remove_patterns that takes in args and patterns and removes
all instances of the patterns from the args.
Sourcepub fn probe_cmd(
self,
temp: String,
chunk_index: usize,
q: f32,
pix_fmt: FFPixelFormat,
probing_rate: usize,
vmaf_threads: usize,
custom_video_params: Option<Vec<String>>,
) -> (Option<Vec<String>>, Vec<Cow<'static, str>>)
pub fn probe_cmd( self, temp: String, chunk_index: usize, q: f32, pix_fmt: FFPixelFormat, probing_rate: usize, vmaf_threads: usize, custom_video_params: Option<Vec<String>>, ) -> (Option<Vec<String>>, Vec<Cow<'static, str>>)
Constructs tuple of commands for target quality probing
pub fn get_format_bit_depth( self, format: FFPixelFormat, ) -> Result<usize, UnsupportedPixelFormatError>